@@ -61,7 +61,6 @@ from .custom_types import (
     _CUSTOM_Float,
     _CUSTOM_Time,
 )
-from .util import _update_connection_application_name
 
 colspecs = {
     Date: _CUSTOM_Date,
@@ -835,12 +834,6 @@ class SnowflakeDialect(default.DefaultDialect):
             else None
         }
 
-    def connect(self, *cargs, **cparams):
-        snowflake_conn = super().connect(
-            *cargs, **_update_connection_application_name(**cparams)
-        )
-        return snowflake_conn
-
 
 @sa_vnt.listens_for(Table, "before_create")
 def check_table(table, connection, _ddl_runner, **kw):
